@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.27"
+version = "1.1.29"
 nvbin_version = "v6.0"
 
 lean_metas = [
@@ -446,7 +446,7 @@ trtpy_lib_root = os.path.join(trtpy_root, "lib")
 cpp_packages_root = os.path.join(trtpy_root, "cpp-packages")
 pydll_path = os.path.join(sys.exec_prefix, "lib")
 pydll_link_name, pydll_full_path = get_python_link_name(pydll_path, os_name)
-inited = False
+sysmode = "NoInit"
 
 module_variables = locals()
 def update_module_variables(module_variables, module):
@@ -534,7 +534,7 @@ def get_cpp_pkg(name):
 
 def __load_symbols(pyc_meta, load_lean_library=True):
 
-    global module_variables, loaded_module, inited
+    global module_variables, loaded_module, sysmode
     select_nvbinary_version = pyc_meta["lean"]
     binary_url_prefix = pyc_meta["binary_url_prefix"]
     lean_meta = list(filter(lambda x:x["name"] == select_nvbinary_version, lean_metas))[0]
@@ -757,7 +757,7 @@ def __load_symbols(pyc_meta, load_lean_library=True):
         clear_all_hook()
 
     atexit.register(exit_call)
-    inited = True
+    sysmode = "Inited"
   
 
 def print_pyc(pyc, i=0):
@@ -788,12 +788,28 @@ def init(cuda_version : str=None, tensorrt_version : str=None, load_lean_library
     load_lean_library: default True
         current support: cuda10.2+trt8.1, cuda11.2+trt8.0
     '''
-
-    if inited:
+    global sysmode
+    if sysmode == "Inited":
         return
 
     global module_variables
     current_kernel_module_driver_version = get_current_driver_version()
+
+    if current_kernel_module_driver_version is None:
+        sysmode = "NoCUDA"
+        module_variables["current_pyc"] = {}
+        module_variables["current_lean"] = {}
+        module_variables["nvlib64_root"] = "unknow"
+        module_variables["select_nvbinary_version"] = "unknow"
+        module_variables["trtexec_path"] = "unknow"
+        module_variables["nv_root"] = "unknow"
+        module_variables["libtrtpro_root"] = "unknow"
+        module_variables["binary_url_prefix"] = "unknow"
+        module_variables["nvbin_root"] = "unknow"
+        module_variables["nvcc_path"] = "unknow"
+        print("Warning: 无法获取驱动版本，您可能无法使用大部分功能。目前完整功能支持在linux x86-64并配有nvidia驱动的设备")
+        return
+
     if current_kernel_module_driver_version is None:
         raise RuntimeError("无法获取驱动版本，请确认是否安装有nvidia显卡驱动，目前仅支持linux x86-64，并且配置有nvidia驱动的设备")
 
