@@ -36,7 +36,7 @@ def do_info(args):
     for key, value in get_variable_template():
         print(f"  {key} = {value}")
 
-    if trtpy.inited:
+    if trtpy.sysmode == "Inited":
         print(f"Current kernel module driver version: {trtpy.current_kernel_module_driver_version}")
         print(f"Support list: {len(trtpy.supported_pycs)} elements")
         for i, pyc in enumerate(trtpy.supported_pycs):
@@ -148,7 +148,7 @@ def get_variable_template():
     variable_template.append(["PYTHON_INCLUDE", f"{sys.exec_prefix}/include/{trtpy.pydll_link_name}"])
     variable_template.append(["PYTHON_LIB", f"{trtpy.pydll_path}"])
     
-    if trtpy.inited:
+    if trtpy.sysmode == "Inited":
         variable_template.append(["TRTPRO_LIB", f"{trtpy.libtrtpro_root}"])
         variable_template.append(["CUDA_HOME", f"{trtpy.nv_root}"])
         variable_template.append(["CUDA_INCLUDE", f"{trtpy.nv_root}/include/cuda"])
@@ -168,7 +168,7 @@ def get_inv_variable_template():
     variable_template.append(["PYTHON_INCLUDE", f"{sys.exec_prefix}/include/{trtpy.pydll_link_name}"])
     variable_template.append(["PYTHON_LIB", f"{trtpy.pydll_path}"])
     
-    if trtpy.inited:
+    if trtpy.sysmode == "Inited":
         variable_template.append(["TRTPRO_LIB", f"{trtpy.libtrtpro_root}"])
         variable_template.append(["CUDA_HOME", f"{trtpy.nv_root}"])
         variable_template.append(["CUDA_INCLUDE", f"{trtpy.nv_root}/include/cuda"])
@@ -271,7 +271,7 @@ def extract_series_templ(meta, saveto, raw, download, cuda, trt):
     local_config_json = os.path.join(series_directory, "config.json")
 
     print(f"Save to {local_config_json}")
-    json.dump(meta, open(local_config_json, "w"), indent=4, ensure_ascii=False)
+    json.dump(meta, open(local_config_json, "w", encoding="utf-8"), indent=4, ensure_ascii=False)
     print(f"Done! current template is {templ_name}, {select_item[1]}")
     return 0
 
@@ -303,7 +303,7 @@ def do_get_series(args):
         print(f"Series '{args.name}' not found")
         return 1
 
-    meta = json.load(open(meta_cache_local_file))
+    meta = json.load(open(meta_cache_local_file, "r", encoding="utf-8"))
     templ_list = meta["list-templ"]
 
     current_index = 0
@@ -323,7 +323,7 @@ def do_change_proj(args):
         print(f"Current is not series folder")
         return 1
 
-    meta = json.load(open(config_json_file, "r"))
+    meta = json.load(open(config_json_file, "r", encoding="utf-8"))
     current_index = meta["current-index"]
     templ_list = meta["list-templ"]
     if len(templ_list) == 0:
@@ -451,7 +451,7 @@ def do_series_detail(args):
             return 1
         config_json_file = meta_cache_local_file
 
-    meta = json.load(open(config_json_file, "r"))
+    meta = json.load(open(config_json_file, "r", encoding="utf-8"))
     current_index = meta["current-index"]
     templ_list = meta["list-templ"]
         
@@ -626,17 +626,17 @@ def do_env_source(args):
     trtpy.init(args.cuda, args.trt)
     save = args.save
     template_file = os.path.join(trtpy.trtpy_root, "environment-template.sh")
-    template_data = open(template_file, "r").read()
+    template_data = open(template_file, "r", encoding="utf-8").read()
     variable_template = get_variable_template()
     template_data, _ = process_code_template.filter_content(template_data, variable_template)
     
     envbase_file = os.path.join(trtpy.nv_root, "env.sh")
-    open(envbase_file, "w").write(template_data)
+    open(envbase_file, "w", encoding="utf-8").write(template_data)
 
     if args.print:
         print(envbase_file, end="")
     else:
-        open(save, "w").write(template_data)
+        open(save, "w", encoding="utf-8").write(template_data)
         print(f"Save to {save}")
 
 def do_invert_variable(args):
